window.Gleam.initSearch([{"doc":"gwt","title":"gwt","content":"# gwt\n\nEncode and decode JWTs.\n\n[![Package Version](https://img.shields.io/hexpm/v/gwt)](https://hex.pm/packages/gwt)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gwt/)\n\n## Quickstart\n\n```gleam\nimport gwt.{type Jwt, type Verified, type Unverified}\n\npub fn main() {\n  let jwt = \n    gwt.new()\n    |&gt; gwt.set_subject(&quot;1234567890&quot;)\n    |&gt; gwt.set_audience(&quot;0987654321&quot;)\n    |&gt; gwt.set_not_before(1_704_043_160)\n    |&gt; gwt.set_expiration(1_704_046_160)\n    |&gt; gwt.set_jwt_id(&quot;2468&quot;)\n\n  let jwt_without_signature = gwt.to_string(jwt)\n  let jwt_with_signature = gwt.to_signed_string(jwt, gwt.HS256, &quot;lucy&quot;)\n\n  let assert Ok(unverified_jwt) = \n    jwt_without_signature\n    |&gt; gwt.from_string()\n\n  let assert Ok(verified_jwt) = \n    jwt_with_signature\n    |&gt;gwt.from_signed_string(&quot;lucy&quot;)\n}\n```\n\n## Installation\n\n```sh\ngleam add gwt \n```\n\nThe documentation can be found at &lt;https://hexdocs.pm/gwt&gt;.\n","url":"index.html"},{"doc":"gwt","title":"Algorithm","content":"pub type Algorithm {\n  HS256\n  HS384\n  HS512\n}\n Available [JSON Web Algorithms](https://datatracker.ietf.org/doc/html/rfc7518#section-3.2) used for encoding and decdoing signatures in [from_signed_string](#from_signed_string) and [to_signed_string](#to_signed_string).\n\n If JWT calls for a different algorithm than the ones listed here [from_signed_string](#from_signed_string) will fail\n with the [JwtDecodeError](#JwtDecodeError) `UnsupportedSigningAlgorithm`.\n\nHS256\n\n\nHS384\n\n\nHS512\n\n\nSynonyms:\ngwt.Algorithm\ngwt Algorithm","url":"gwt.html#Algorithm"},{"doc":"gwt","title":"Jwt","content":"pub opaque type Jwt(status)\n\n\nSynonyms:\ngwt.Jwt\ngwt Jwt","url":"gwt.html#Jwt"},{"doc":"gwt","title":"JwtDecodeError","content":"pub type JwtDecodeError {\n  MissingHeader\n  MissingPayload\n  MissingSignature\n  InvalidHeader\n  InvalidPayload\n  InvalidSignature\n  InvalidExpiration\n  TokenExpired\n  TokenNotValidYet\n  InvalidNotBefore\n  NoAlg\n  InvalidAlg\n  UnsupportedSigningAlgorithm\n  MissingClaim\n  InvalidClaim(List(DecodeError))\n}\n\nMissingHeader\n\n\nMissingPayload\n\n\nMissingSignature\n\n\nInvalidHeader\n\n\nInvalidPayload\n\n\nInvalidSignature\n\n\nInvalidExpiration\n\n\nTokenExpired\n\n\nTokenNotValidYet\n\n\nInvalidNotBefore\n\n\nNoAlg\n\n\nInvalidAlg\n\n\nUnsupportedSigningAlgorithm\n\n\nMissingClaim\n\n\nInvalidClaim(List(DecodeError))\n\n\nSynonyms:\ngwt.JwtDecodeError\ngwt JwtDecodeError","url":"gwt.html#JwtDecodeError"},{"doc":"gwt","title":"Unverified","content":"pub type Unverified\n A phantom type representing an unverified Jwt.\n\n\nSynonyms:\ngwt.Unverified\ngwt Unverified","url":"gwt.html#Unverified"},{"doc":"gwt","title":"Verified","content":"pub type Verified\n A phantom type representing a Jwt successfully decoded from a signed string.\n\n\nSynonyms:\ngwt.Verified\ngwt Verified","url":"gwt.html#Verified"},{"doc":"gwt","title":"from_signed_string","content":"pub fn from_signed_string(\n  jwt_string: String,\n  secret: String,\n) -&gt; Result(Jwt(Verified), JwtDecodeError)\n Decode a signed JWT string into a verified [Jwt](#Jwt).\n \n Returns `Ok(Jwt(Unverified))` if it is a valid JWT and the JWT&#39;s signature is successfully verified,\n and `Error(JwtDecodeError)` otherwise.\n\n At the moment this library only supports `HS256`, `HS384`, and `HS512` hashing algorithms.\n if a JWT&#39;s alg claim calls for any other this function will return `Error(UnsupportedSigningAlgorithm)`.\n\n \n import gwt.{type Jwt, type Verified, type JwtDecodeError}\n \n fn example(jwt_string: String) -&gt; Result(Jwt(Verified), JwtDecodeError) {\n   gwt.from_signed_string(jwt_string, &quot;some secret&quot;)\n }\n \n\nSynonyms:\ngwt.from_signed_string\ngwt from_signed_string","url":"gwt.html#from_signed_string"},{"doc":"gwt","title":"from_string","content":"pub fn from_string(\n  jwt_string: String,\n) -&gt; Result(Jwt(Unverified), JwtDecodeError)\n Decode a JWT string into an unverified [Jwt](#Jwt).\n \n Returns `Ok(Jwt(Unverified))` if it is a valid JWT, and `Error(JwtDecodeError)` otherwise.\n\n \n import gwt.{type Jwt, type Unverified, type JwtDecodeError}\n \n fn example(jwt_string: String) -&gt; Result(Jwt(Unverified), JwtDecodeError) {\n   gwt.from_string(jwt_string)\n }\n \n\nSynonyms:\ngwt.from_string\ngwt from_string","url":"gwt.html#from_string"},{"doc":"gwt","title":"get_audience","content":"pub fn get_audience(\n  from jwt: Jwt(a),\n) -&gt; Result(String, JwtDecodeError)\n Retrieve the aud from the JWT&#39;s payload.\n\n Returns `Error(Nil)` if the sub is not present or if it is invalid.\n\n If you know the aud claim is not of type `String` you can use [get_payload_claim](#get_payload_claim)\n to retrieve and decode it manually.\n\n \n import gwt\n \n fn example()  {\n   let jwt_with_aud = \n     gwt.new()\n     |&gt; jwt.set_audience(&quot;gleam&quot;)\n \n   let assert Ok(audience) = gwt.get_audience(jwt_with_aud)\n \n   let jwt_without_aud = gwt.new()\n \n   let assert Error(MissingClaim) = gwt.get_audience(jwt_without_aud)\n }\n \n\nSynonyms:\ngwt.get_audience\ngwt get_audience","url":"gwt.html#get_audience"},{"doc":"gwt","title":"get_expiration","content":"pub fn get_expiration(\n  from jwt: Jwt(a),\n) -&gt; Result(Int, JwtDecodeError)\n Retrieve the exp from the JWT&#39;s payload.\n\n Returns `Error(Nil)` if the exp is not present or if it is invalid.\n\n If you know the exp claim is not of type `String` you can use [get_payload_claim](#get_payload_claim)\n to retrieve and decode it manually.\n\n \n import gwt\n \n fn example()  {\n   let jwt_with_exp = \n     gwt.new()\n     |&gt; jwt.set_not_before(&quot;gleam&quot;)\n \n   let assert Ok(expiration) = gwt.get_not_before(jwt_with_exp)\n \n   let jwt_without_exp = gwt.new()\n \n   let assert Error(MissingClaim) = gwt.get_not_before(jwt_without_exp)\n }\n \n\nSynonyms:\ngwt.get_expiration\ngwt get_expiration","url":"gwt.html#get_expiration"},{"doc":"gwt","title":"get_header_claim","content":"pub fn get_header_claim(\n  from jwt: Jwt(a),\n  claim claim: String,\n  decoder decoder: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; Result(b, Nil)\n Retrieve and decode a claim from a JWT&#39;s header.\n\n Returns `Error` if the claim is not present or if it is invalid based on the passed in decoder.\n\n \n import gwt\n import gleam/json\n import gleam/dynamic\n \n fn example() {\n   let jwt_with_custom_claim =\n     gwt.new()\n     |&gt; gwt.set_header_claim(&quot;gleam&quot;, json.string(&quot;lucy&quot;))\n \n   let assert Ok(&quot;lucy&quot;) =\n     gwt.get_header_claim(jwt_with_custom_claim, &quot;gleam&quot;, dynamic.string)\n \n   let assert Error(MissingClaim) =\n     gwt.get_header_claim(jwt_with_custom_claim, &quot;gleam&quot;, dynamic.int)\n }\n \n\nSynonyms:\ngwt.get_header_claim\ngwt get_header_claim","url":"gwt.html#get_header_claim"},{"doc":"gwt","title":"get_issued_at","content":"pub fn get_issued_at(\n  from jwt: Jwt(a),\n) -&gt; Result(Int, JwtDecodeError)\n Retrieve the iat from the JWT&#39;s payload.\n\n Returns `Error(Nil)` if the iat is not present or if it is invalid.\n\n If you know the iat claim is not of type `String` you can use [get_payload_claim](#get_payload_claim)\n to retrieve and decode it manually.\n\n \n import gwt\n \n fn example()  {\n   let jwt_with_iat = \n     gwt.new()\n     |&gt; jwt.set_issued_at(&quot;gleam&quot;)\n \n   let assert Ok(issued_at) = gwt.get_issued_at(jwt_with_iat)\n \n   let jwt_without_iat = gwt.new()\n \n   let assert Error(MissingClaim) = gwt.get_issued_at(jwt_without_iat)\n }\n \n\nSynonyms:\ngwt.get_issued_at\ngwt get_issued_at","url":"gwt.html#get_issued_at"},{"doc":"gwt","title":"get_issuer","content":"pub fn get_issuer(\n  from jwt: Jwt(a),\n) -&gt; Result(String, JwtDecodeError)\n Retrieve the iss from the JWT&#39;s payload.\n\n Returns `Error(Nil)` if the iss is not present or if it is invalid.\n\n If you know the iss claim is not of type `String` you can use [get_payload_claim](#get_payload_claim)\n to retrieve and decode it manually.\n\n \n import gwt\n \n fn example()  {\n   let jwt_with_iss = \n     gwt.new()\n     |&gt; jwt.set_issuer(&quot;gleam&quot;)\n \n   let assert Ok(issuer) = gwt.get_issuer(jwt_with_iss)\n \n   let jwt_without_iss = gwt.new()\n \n   let assert Error(MissingClaim) = gwt.get_issuer(jwt_without_iss)\n }\n \n\nSynonyms:\ngwt.get_issuer\ngwt get_issuer","url":"gwt.html#get_issuer"},{"doc":"gwt","title":"get_jwt_id","content":"pub fn get_jwt_id(\n  from jwt: Jwt(a),\n) -&gt; Result(String, JwtDecodeError)\n Retrieve the jti from the JWT&#39;s payload.\n\n Returns `Error(Nil)` if the jti is not present or if it is invalid.\n\n If you know the jti claim is not of type `String` you can use [get_payload_claim](#get_payload_claim)\n to retrieve and decode it manually.\n\n \n import gwt\n \n fn example()  {\n   let jwt_with_jti = \n     gwt.new()\n     |&gt; jwt.set_jwt_id(&quot;gleam&quot;)\n \n   let assert Ok(jwt_id) = gwt.get_jwt_id(jwt_with_jti)\n \n   let jwt_without_jti = gwt.new()\n \n   let assert Error(MissingClaim) = gwt.get_jwt_id(jwt_without_jti)\n }\n \n\nSynonyms:\ngwt.get_jwt_id\ngwt get_jwt_id","url":"gwt.html#get_jwt_id"},{"doc":"gwt","title":"get_not_before","content":"pub fn get_not_before(\n  from jwt: Jwt(a),\n) -&gt; Result(Int, JwtDecodeError)\n Retrieve the nbf from the JWT&#39;s payload.\n\n Returns `Error(Nil)` if the nbf is not present or if it is invalid.\n\n If you know the nbf claim is not of type `String` you can use [get_payload_claim](#get_payload_claim)\n to retrieve and decode it manually.\n\n \n import gwt\n \n fn example()  {\n   let jwt_with_sub = \n     gwt.new()\n     |&gt; jwt.set_not_before(&quot;gleam&quot;)\n \n   let assert Ok(not_before) = gwt.get_not_before(jwt_with_nbf)\n \n   let jwt_without_nbf = gwt.new()\n \n   let assert Error(MissingClaim) = gwt.get_not_before(jwt_without_nbf)\n }\n \n\nSynonyms:\ngwt.get_not_before\ngwt get_not_before","url":"gwt.html#get_not_before"},{"doc":"gwt","title":"get_payload_claim","content":"pub fn get_payload_claim(\n  from jwt: Jwt(a),\n  claim claim: String,\n  decoder decoder: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; Result(b, JwtDecodeError)\n Retrieve and decode a claim from a JWT&#39;s payload.\n\n Returns `Error` if the claim is not present or if it is invalid based on the passed in decoder.\n\n \n import gwt\n import gleam/json\n import gleam/dynamic\n \n fn example() {\n   let jwt_with_custom_claim =\n     gwt.new()\n     |&gt; gwt.set_payload_claim(&quot;gleam&quot;, json.string(&quot;lucy&quot;))\n \n   let assert Ok(&quot;lucy&quot;) =\n     gwt.get_payload_claim(jwt_with_custom_claim, &quot;gleam&quot;, dynamic.string)\n \n   let assert Error(MissingClaim) =\n     gwt.get_payload_claim(jwt_with_custom_claim, &quot;gleam&quot;, dynamic.int)\n }\n \n\nSynonyms:\ngwt.get_payload_claim\ngwt get_payload_claim","url":"gwt.html#get_payload_claim"},{"doc":"gwt","title":"get_subject","content":"pub fn get_subject(\n  from jwt: Jwt(a),\n) -&gt; Result(String, JwtDecodeError)\n Retrieve the sub from the JWT&#39;s payload.\n\n Returns `Error(Nil)` if the sub is not present or if it is invalid.\n\n If you know the sub claim is not of type `String` you can use [get_payload_claim](#get_payload_claim)\n to retrieve and decode it manually.\n\n \n import gwt\n \n fn example()  {\n   let jwt_with_sub = \n     gwt.new()\n     |&gt; jwt.set_subject(&quot;gleam&quot;)\n \n   let assert Ok(subject) = gwt.get_issuer(jwt_with_sub)\n \n   let jwt_without_sub = gwt.new()\n \n   let assert Error(MissingClaim) = gwt.get_subject(jwt_without_sub)\n }\n \n\nSynonyms:\ngwt.get_subject\ngwt get_subject","url":"gwt.html#get_subject"},{"doc":"gwt","title":"new","content":"pub fn new() -&gt; Jwt(Unverified)\n Creates an [Unverified](#Unverified) Jwt with an empty payload and a header that only \n contains the cliams `&quot;typ&quot;: &quot;JWT&quot;`, and `&quot;alg&quot;: &quot;none&quot;`.\n\n \n import gwt.{type Jwt, type Unverified}\n \n fn example() -&gt; Jwt(Unverified) {\n   gwt.new()\n }\n \n\nSynonyms:\ngwt.new\ngwt new","url":"gwt.html#new"},{"doc":"gwt","title":"set_audience","content":"pub fn set_audience(\n  jwt: Jwt(a),\n  to aud: String,\n) -&gt; Jwt(Unverified)\n Set the aud claim of a payload, and changing the JWT to unverified.\n\n \n import gwt\n \n fn example() {\n   gwt.new()\n   |&gt; gwt.set_audience(&quot;gleam&quot;)\n }\n  \n\nSynonyms:\ngwt.set_audience\ngwt set_audience","url":"gwt.html#set_audience"},{"doc":"gwt","title":"set_expiration","content":"pub fn set_expiration(\n  jwt: Jwt(a),\n  to exp: Int,\n) -&gt; Jwt(Unverified)\n Set the exp claim of a payload, and changing the JWT to unverified.\n\n \n import gwt\n import birl\n \n fn example() {\n   let five_minutes = birl.to_unix(birl.now()) + 300\n \n   gwt.new()\n   |&gt; gwt.set_expiration(five_minutes)\n }\n  \n\nSynonyms:\ngwt.set_expiration\ngwt set_expiration","url":"gwt.html#set_expiration"},{"doc":"gwt","title":"set_header_claim","content":"pub fn set_header_claim(\n  jwt: Jwt(a),\n  set claim: String,\n  to value: Json,\n) -&gt; Jwt(Unverified)\n Set a custom header claim to a given JSON value, and changing the JWT to unverified.\n\n \n import gleam/json\n import gwt\n \n fn example() {\n   gwt.new()\n   |&gt; gwt.set_header_claim(&quot;gleam&quot;, json.string(&quot;lucy&quot;))\n }\n  \n\nSynonyms:\ngwt.set_header_claim\ngwt set_header_claim","url":"gwt.html#set_header_claim"},{"doc":"gwt","title":"set_issued_at","content":"pub fn set_issued_at(jwt: Jwt(a), to iat: Int) -&gt; Jwt(Unverified)\n Set the nbf claim of a payload, and changing the JWT to unverified.\n\n \n import gwt\n import birl\n \n fn example() {\n   gwt.new()\n   |&gt; gwt.set_not_before(birl.to_unix(birl.now()))\n }\n  \n\nSynonyms:\ngwt.set_issued_at\ngwt set_issued_at","url":"gwt.html#set_issued_at"},{"doc":"gwt","title":"set_issuer","content":"pub fn set_issuer(jwt: Jwt(a), to iss: String) -&gt; Jwt(Unverified)\n Set the iss claim of a payload, and changing the JWT to unverified.\n\n \n import gwt\n \n fn example() {\n   gwt.new()\n   |&gt; gwt.set_issuer(&quot;gleam&quot;)\n }\n  \n\nSynonyms:\ngwt.set_issuer\ngwt set_issuer","url":"gwt.html#set_issuer"},{"doc":"gwt","title":"set_jwt_id","content":"pub fn set_jwt_id(jwt: Jwt(a), to jti: String) -&gt; Jwt(Unverified)\n Set the jti claim of a payload, and changing the JWT to unverified.\n\n \n import gwt\n import birl\n \n fn example() {\n   gwt.new()\n   |&gt; gwt.set_jwt_id(&quot;gleam&quot;)\n }\n  \n\nSynonyms:\ngwt.set_jwt_id\ngwt set_jwt_id","url":"gwt.html#set_jwt_id"},{"doc":"gwt","title":"set_not_before","content":"pub fn set_not_before(\n  jwt: Jwt(a),\n  to nbf: Int,\n) -&gt; Jwt(Unverified)\n Set the nbf claim of a payload, and changing the JWT to unverified.\n\n \n import gwt\n import birl\n \n fn example() {\n   let five_minutes = birl.to_unix(birl.now()) + 300\n \n   gwt.new()\n   |&gt; gwt.set_not_before(five_minutes)\n }\n  \n\nSynonyms:\ngwt.set_not_before\ngwt set_not_before","url":"gwt.html#set_not_before"},{"doc":"gwt","title":"set_payload_claim","content":"pub fn set_payload_claim(\n  jwt: Jwt(a),\n  set claim: String,\n  to value: Json,\n) -&gt; Jwt(Unverified)\n Set a custom payload claim to a given JSON value, and changing the JWT to unverified.\n\n \n import gleam/json\n import gwt\n \n fn example() {\n   gwt.new()\n   |&gt; gwt.set_payload_claim(&quot;gleam&quot;, json.string(&quot;lucy&quot;))\n }\n  \n\nSynonyms:\ngwt.set_payload_claim\ngwt set_payload_claim","url":"gwt.html#set_payload_claim"},{"doc":"gwt","title":"set_subject","content":"pub fn set_subject(\n  jwt: Jwt(a),\n  to sub: String,\n) -&gt; Jwt(Unverified)\n Set the sub claim of a payload, and changing the JWT to unverified.\n\n \n import gwt\n \n fn example() {\n   gwt.new()\n   |&gt; gwt.set_subject(&quot;gleam&quot;)\n }\n  \n\nSynonyms:\ngwt.set_subject\ngwt set_subject","url":"gwt.html#set_subject"},{"doc":"gwt","title":"to_signed_string","content":"pub fn to_signed_string(\n  jwt: Jwt(a),\n  alg: Algorithm,\n  secret: String,\n) -&gt; String\n Encode a [Jwt](#Jwt) to a signed String using the given [Algorithm](#Algorithm) and secret.\n\n \n import gwt\n \n fn example() {\n   gwt.new()\n   |&gt; gwt.set_issuer(&quot;gleam&quot;)\n   |&gt; gwt.to_signed_string(gwt.HS256, &quot;lucy&quot;)\n }\n  \n\nSynonyms:\ngwt.to_signed_string\ngwt to_signed_string","url":"gwt.html#to_signed_string"},{"doc":"gwt","title":"to_string","content":"pub fn to_string(jwt: Jwt(a)) -&gt; String\n Encode a [Jwt](#Jwt) to a String without a signature\n\n \n import gwt\n \n fn example() {\n   gwt.new()\n   |&gt; gwt.set_issuer(&quot;gleam&quot;)\n   |&gt; gwt.to_string()\n }\n  \n\nSynonyms:\ngwt.to_string\ngwt to_string","url":"gwt.html#to_string"},{"doc":"gwt","title":"gwt","content":"","url":"gwt.html"}]);